]> sigrok.org Git - libsigrok.git/blobdiff - strutil.c
strutil: Now using base 10 in sr_atol(), sr_atoi() for compatibility to atoi(), atol...
[libsigrok.git] / strutil.c
index 01bdbd11bcf821f75e10a35f781c0552553ee7ed..47975d2048165992b0d9fbc532617212bd9cb871 100644 (file)
--- a/strutil.c
+++ b/strutil.c
@@ -46,7 +46,7 @@
 /**
  * @private
  *
* Convert a string representation of a numeric value to a long integer. The
  * conversion is strict and will fail if the complete string does not represent
  * a valid long integer. The function sets errno according to the details of the
  * failure.
@@ -54,7 +54,8 @@
  * @param str The string representation to convert.
  * @param ret Pointer to long where the result of the conversion will be stored.
  *
- * @return SR_OK if conversion is successful, otherwise SR_ERR.
+ * @retval SR_OK Conversion successful.
+ * @retval SR_ERR Failure.
  *
  * @since 0.3.0
  */
@@ -64,7 +65,7 @@ SR_PRIV int sr_atol(const char *str, long *ret)
        char *endptr = NULL;
 
        errno = 0;
-       tmp = strtol(str, &endptr, 0);
+       tmp = strtol(str, &endptr, 10);
 
        if (!endptr || *endptr || errno) {
                if (!errno)
@@ -79,7 +80,7 @@ SR_PRIV int sr_atol(const char *str, long *ret)
 /**
  * @private
  *
* Convert a string representation of a numeric value to an integer. The
  * conversion is strict and will fail if the complete string does not represent
  * a valid integer. The function sets errno according to the details of the
  * failure.
@@ -87,7 +88,8 @@ SR_PRIV int sr_atol(const char *str, long *ret)
  * @param str The string representation to convert.
  * @param ret Pointer to int where the result of the conversion will be stored.
  *
- * @return SR_OK if conversion is successful, otherwise SR_ERR.
+ * @retval SR_OK Conversion successful.
+ * @retval SR_ERR Failure.
  *
  * @since 0.3.0
  */
@@ -118,7 +120,8 @@ SR_PRIV int sr_atoi(const char *str, int *ret)
  * @param str The string representation to convert.
  * @param ret Pointer to double where the result of the conversion will be stored.
  *
- * @return SR_OK if conversion is successful, otherwise SR_ERR.
+ * @retval SR_OK Conversion successful.
+ * @retval SR_ERR Failure.
  *
  * @since 0.3.0
  */
@@ -151,7 +154,8 @@ SR_PRIV int sr_atod(const char *str, double *ret)
  * @param str The string representation to convert.
  * @param ret Pointer to float where the result of the conversion will be stored.
  *
- * @return SR_OK if conversion is successful, otherwise SR_ERR.
+ * @retval SR_OK Conversion successful.
+ * @retval SR_ERR Failure.
  *
  * @since 0.3.0
  */
@@ -182,7 +186,8 @@ SR_PRIV int sr_atof(const char *str, float *ret)
  * @param str The string representation to convert.
  * @param ret Pointer to float where the result of the conversion will be stored.
  *
- * @return SR_OK if conversion is successful, otherwise SR_ERR.
+ * @retval SR_OK Conversion successful.
+ * @retval SR_ERR Failure.
  *
  * @since 0.3.0
  */
@@ -228,6 +233,8 @@ SR_PRIV int sr_atof_ascii(const char *str, float *ret)
  * @return A g_try_malloc()ed string representation of the samplerate value,
  *         or NULL upon errors. The caller is responsible to g_free() the
  *         memory.
+ *
+ * @since 0.2.0
  */
 SR_API char *sr_si_string_u64(uint64_t x, const char *unit)
 {
@@ -268,6 +275,8 @@ SR_API char *sr_si_string_u64(uint64_t x, const char *unit)
  * @return A g_try_malloc()ed string representation of the samplerate value,
  *         or NULL upon errors. The caller is responsible to g_free() the
  *         memory.
+ *
+ * @since 0.1.0
  */
 SR_API char *sr_samplerate_string(uint64_t samplerate)
 {
@@ -285,6 +294,8 @@ SR_API char *sr_samplerate_string(uint64_t samplerate)
  * @return A g_try_malloc()ed string representation of the frequency value,
  *         or NULL upon errors. The caller is responsible to g_free() the
  *         memory.
+ *
+ * @since 0.1.0
  */
 SR_API char *sr_period_string(uint64_t frequency)
 {
@@ -328,6 +339,8 @@ SR_API char *sr_period_string(uint64_t frequency)
  * @return A g_try_malloc()ed string representation of the voltage value,
  *         or NULL upon errors. The caller is responsible to g_free() the
  *         memory.
+ *
+ * @since 0.2.0
  */
 SR_API char *sr_voltage_string(uint64_t v_p, uint64_t v_q)
 {
@@ -377,6 +390,8 @@ SR_API char *sr_voltage_string(uint64_t v_p, uint64_t v_q)
  *         a trigger value set in 'triggerstring' are NULL, the other entries
  *         contain the respective trigger type which is requested for the
  *         respective channel (e.g. "r", "c", and so on).
+ *
+ * @since 0.2.0
  */
 SR_API char **sr_parse_triggerstring(const struct sr_dev_inst *sdi,
                                     const char *triggerstring)
@@ -463,6 +478,8 @@ SR_API char **sr_parse_triggerstring(const struct sr_dev_inst *sdi,
  * @param size Pointer to uint64_t which will contain the string's size value.
  *
  * @return SR_OK upon success, SR_ERR upon errors.
+ *
+ * @since 0.1.0
  */
 SR_API int sr_parse_sizestring(const char *sizestring, uint64_t *size)
 {
@@ -528,6 +545,8 @@ SR_API int sr_parse_sizestring(const char *sizestring, uint64_t *size)
  * @todo Add support for "m" (minutes) and others.
  * @todo Add support for picoseconds?
  * @todo Allow both lower-case and upper-case? If no, document it.
+ *
+ * @since 0.1.0
  */
 SR_API uint64_t sr_parse_timestring(const char *timestring)
 {
@@ -554,6 +573,7 @@ SR_API uint64_t sr_parse_timestring(const char *timestring)
        return time_msec;
 }
 
+/** @since 0.1.0 */
 SR_API gboolean sr_parse_boolstring(const char *boolstr)
 {
        if (!boolstr)
@@ -568,6 +588,7 @@ SR_API gboolean sr_parse_boolstring(const char *boolstr)
        return FALSE;
 }
 
+/** @since 0.2.0 */
 SR_API int sr_parse_period(const char *periodstr, uint64_t *p, uint64_t *q)
 {
        char *s;
@@ -600,7 +621,7 @@ SR_API int sr_parse_period(const char *periodstr, uint64_t *p, uint64_t *q)
        return SR_OK;
 }
 
-
+/** @since 0.2.0 */
 SR_API int sr_parse_voltage(const char *voltstr, uint64_t *p, uint64_t *q)
 {
        char *s;
@@ -46,7 +46,7 @@
  * @private
  *
- * Convert a string representation of a numeric value to a long integer. The
+ * Convert a string representation of a numeric value (base 10) to a long integer. The
  * conversion is strict and will fail if the complete string does not represent
  * a valid long integer. The function sets errno according to the details of the
@@ -79,7 +80,7 @@ SR_PRIV int sr_atol(const char *str, long *ret)
  * @private
  *
- * Convert a string representation of a numeric value to an integer. The
+ * Convert a string representation of a numeric value (base 10) to an integer. The
  * conversion is strict and will fail if the complete string does not represent
  * a valid integer. The function sets errno according to the details of the